<?php

namespace Slovocast\Domain\Repository\Channel;

use Slovocast\Domain\Entity\Episode;
use Slovocast\Domain\Aggregate\ChannelAggregate;
use Slovocast\Domain\Repository\Channel\ChannelRepositoryInterface;
use Slovocast\Domain\Repository\Episode\EpisodeRepositoryInterface;
use Slovocast\Infrastructure\Api\Database\DatabaseHandlerInterface;

class ChannelAggregateRepository
{
    public function __construct(
        protected DatabaseHandlerInterface $database,
        protected ChannelRepositoryInterface $channelRepository,
        protected EpisodeRepositoryInterface $episodeRepository,
    ) { }

    public function getChannelWithEpisodes(int $id): ChannelAggregate
    {
        $channel = $this->channelRepository->get($id);
        $episodes = $this->episodeRepository->getFromChannel($channel);
        return new ChannelAggregate($channel, $episodes);
    }

    public function getChannelByEpisode(Episode $episode): ChannelAggregate
    {
        $query = "SELECT c.id as channel_id, e.id as episode_id
            FROM channel c
            LEFT JOIN episodes e ON e.channel_id = c.id
            WHERE e.id = :id";

        $results = $this->database->query($query, [
            ":id" => $episode->getId()
        ]);

        $row = array_shift($results);
        return $this->getChannelByEpisode($row['id']);
    }
}
